"""
Main entry point for the Noir package when run as a module.

This module provides the main entry point for the Noir package when run as a module.
"""

import sys
from noir.cli import main

if __name__ == "__main__":
    sys.exit(main())
